--[[
	UO_OGRANISER:
	'uo' (unOfficial) Version by Hoshizora [http://hoshizora.tripod.com/uo_ograniser]
	Original Concept and Program by modsyn [http://cs.ulm.edu/~jself]

	Uses LUA Player: 0.20 MOD 2 by Cools [http://www.theriddlingsphinx.com/]
	Last updated   : 2006.07.20
  ]]

----------------------
-- Import Libraries --
----------------------
require('lib/util')

-----------------------------
-- Global vars (Constants) --
-----------------------------
-- Hoshizora 2006.07.17: Program & debug info
progname='uo_Ograniser'
progver ='0.9.0'
debug   =false

-- Activate USB mode (for development stage use only)
--System.usbDiskModeActivate()

-- Hoshizora 2006.07.17: Screen titles
list1_0title='FW1.0 Homebrew'
list1_5title='FW1.5 Homebrew'
reporttitle ='Summary Report'

-- Hoshizora 2006.07.08: File/dir locations
gamedir     ='ms0:/PSP/GAME/'
imagesdir   ='images/'
logfiledir  ='ms0:/Ogranise.log'
screencapdir='ms0:/Ogranise.png'

-- Hoshizora 2006.07.17: Screen info used mainly by print command
fontdim     =8   -- Font dimension (8x8)
screenwidth =480 -- Can accomodate 59 characters per line (screenwidth/fontdim)-1 based on fontdim (8x8)
screenheight=272 -- Can accomodate 33 lines (screenheight/fontdim)-1 based on fontdim (8x8)
maxtitlelen =39  -- Used by pad_right and pad_left for report screen
black =Color.new(0,0,0)
white =Color.new(255,255,255)
red   =Color.new(255,0,0)
green =Color.new(0,240,0)
blue  =Color.new(30,30,230)
yellow=Color.new(255,255,0)

-- Hoshizora 2006.07.17: Program images
os              =Image.createEmpty(screenwidth,screenheight)
splashbg        =Image.load(imagesdir..'bg-splash.png')
mainbg          =Image.load(imagesdir..'bg-main.png')
contextbg       =Image.load(imagesdir..'bg-context.png')
reportbg        =Image.load(imagesdir..'bg-report.png')
padup           =Image.load(imagesdir..'pad-up.png')
paddown         =Image.load(imagesdir..'pad-down.png')
padleft         =Image.load(imagesdir..'pad-left.png')
padright        =Image.load(imagesdir..'pad-right.png')
padtriangle     =Image.load(imagesdir..'pad-triangle.png')
padsquare       =Image.load(imagesdir..'pad-square.png')
padcircle       =Image.load(imagesdir..'pad-circle.png')
padcross        =Image.load(imagesdir..'pad-cross.png')
padl            =Image.load(imagesdir..'pad-l.png')
padr            =Image.load(imagesdir..'pad-r.png')
padselect       =Image.load(imagesdir..'pad-select.png')
padstart        =Image.load(imagesdir..'pad-start.png')
analogleft      =Image.load(imagesdir..'analog-left.png')
iconbattery     =Image.load(imagesdir..'icon-battery.png')
iconlistlocked  =Image.load(imagesdir..'icon-listlocked.png')
iconlistunlocked=Image.load(imagesdir..'icon-listunlocked.png')

-- Hoshizora 2006.07.08: Messages for the status bar
msg1_0HomebrewsInTotal=' title(s) for firmware 1.0 in total'
msg1_5HomebrewsInTotal=' KXploit title(s) for firmware 1.5 in total'
msgManualSort         ='Move the selection using D-pad or analog stick'
msgAutoSort           ='The FW1.5 Homebrew list sorted in '
msgRestoreOriginalList='The original FW1.5 list order has been restored'
msgEditDisabled       ='The FW1.0 Homebrew list cannot be edited'
msgIsLowBattery       ='Battery power is low. Please recharge and try again'
msgScreenCaptured     ='Screen capture saved to ' .. screencapdir
msgDispHideOption     ='Hide KXploit shortcut folders in list'
msgDispShowOption     ='Display KXploit shortcut folders in list'
msgIconRepairOption   ='Corrupted icons will be repaired during ogranising'
msgIconRestoreOption  ='Corrupted icons will be restored during ogranising'
msgIconNoChangeOption ='No changes will be made to the icons during ogranising'
msgReportScreen       ='Press     to return to Splash Screen or    to Quit'
msgYNCommitChanges    ='Commit changes made to the Current Listing?'
msgYNQuitOgraniser    ='Do you wish to quit uo_Ograniser?'

-- Pad controls
analogDeadZone=32 -- Sensitivity of the analog D-pad

-------------------
-- Main Function --
-------------------
--Hoshizora 2006.07.15: Main program function
function main()
	local prog1_5={}
	local list1_5={}
	local list1_0={}
	local sel=nil
	local max

	while true do
		getGameList(prog1_5,list1_5,list1_0)
		osSplashScreen()

		repeat
			sel,repair=choose(list1_5title,list1_5,list1_0)
			if sel then
				--Hoshizora 2006.07.09: Remove Ogranise.log file from previous run (if exist)
				if fileExists(logfiledir) then
					System.removeFile(logfiledir)
				end
				osClear()
				max=table.getn(sel)
				for i=1,max do
					--Hoshizora 2006.07.07: Modified touch_icon function to include repair mode, current and max queue counter
					touch_shortcut(prog1_5,sel[max-i+1],repair,i,max)
				end
			end
		until sel

		osClear()
		osReportScreen()

		while true do
			Pad:Update()
			if Pad.St then break end
			--Hoshizora 2006.07.08: Assign SELECT button to screen capture function
			if Pad.Sl then screen:save(screencapdir) end
		end
	end
end

------------------
-- Main Program --
------------------
main()